@@ -775,7 +775,10 @@ class MapCalcsGeneric(object):
 		if (spk_ts.ndim == 2):
 			spk_ts = np.ravel(spk_ts)
 		self.spk_ts = spk_ts
-		self.plot_type = plot_type
+		if type(plot_type) is str:
+			self.plot_type = [plot_type]
+		else:
+			self.plot_type = list(plot_type)
 		self.spk_pos_idx = self.__interpSpkPosTimes()
 		self.__good_clusters = None
 		self.__spk_clusters = None
@@ -839,6 +842,8 @@ class MapCalcsGeneric(object):
 			what_to_plot = ['map','path','hdir','sac','speed', 'sp_hd']
 			fig = plt.figure(figsize=(20,10))
 		else:
+			if type(self.plot_type) is str:
+				what_to_plot = [self.plot_type]
 			what_to_plot = list(self.plot_type)
 			if len(what_to_plot) > 1:
 				fig = plt.figure(figsize=(20,10))
@@ -849,10 +854,14 @@ class MapCalcsGeneric(object):
 		outer = gridspec.GridSpec(nrows, nrows, figure=fig)
 
 		inner_ncols = int(np.ceil(len(what_to_plot) / 2)) # max 2 cols
+		print(f"what_to_plot: {what_to_plot}")
 		if len(what_to_plot) == 1:
 			inner_nrows = 1
 		else:
 			inner_nrows = 2
+		print(f"inner_ncols: {inner_ncols}")
+		print(f"inner_nrows: {inner_nrows}")
+		print(f"nrows: {nrows}")
 		for i, cluster in enumerate(self.good_clusters):
 			inner = gridspec.GridSpecFromSubplotSpec(inner_nrows,inner_ncols, subplot_spec=outer[i])
 			for plot_type_idx, plot_type in enumerate(what_to_plot):
@@ -995,7 +1004,7 @@ class MapCalcsGeneric(object):
 			if ax is None:
 				fig = plt.figure()
 				ax = fig.add_subplot(111, projection='polar')
-			theta = np.deg2rad(rmap[1][0][1:])
+			theta = np.deg2rad(rmap[1][0])
 			ax.clear()
 			r = rmap[0]
 			r = np.insert(r, -1, r[0])
@@ -1092,9 +1101,18 @@ class MapCalcsGeneric(object):
 		gridness,scale,orientation,HDtuning,HDangle,speedCorr,speedMod = [],[],[],[],[],[],[]
 		for i,cl in enumerate(cluster):
 			rmap = self.makeRateMap(cl, None)
-			m = self.makeSAC(rmap, cl, None)
-			r,th = self.getHDtuning(cl)
-			spC,spM = self.getSpeedTuning(cl)
+			try:
+				m = self.makeSAC(rmap, cl, None)
+			except:
+				m = np.nan
+			try:
+				r,th = self.getHDtuning(cl)
+			except:
+				r = th = np.nan
+			try:
+				spC,spM = self.getSpeedTuning(cl)
+			except:
+				spC = spM = np.nan
 			
 			gridness.append(m['gridness'])
 			scale.append(m['scale'])
@@ -1687,10 +1705,10 @@ class FieldCalcs:
 			map1 = misc.imresize(map1, map2.shape, interp='nearest', mode='F')
 		map1 = map1.flatten()
 		map2 = map2.flatten()
-		if maptype is 'normal':
+		if 'normal' in maptype:
 			valid_map1 = np.logical_or((map1 > 0), ~np.isnan(map1))
 			valid_map2 = np.logical_or((map2 > 0), ~np.isnan(map2))
-		elif maptype is 'grid':
+		elif 'grid' in maptype:
 			valid_map1 = ~np.isnan(map1)
 			valid_map2 = ~np.isnan(map2)
 		valid = np.logical_and(valid_map1, valid_map2)
