@@ -239,10 +239,10 @@ class OpenEphysBase(object):
 		self.hdir = hdir
 		spk_times = (self.kilodata.spk_times.T / 3e4)
 		if 'plot_type' in kwargs.keys():
-			plot_type = kwargs['plot_type']
+			plot_type = kwargs.pop('plot_type')
 		else:
 			plot_type = 'map'
-		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type=plot_type, **kwargs)
+		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
 		if 'cluster' in kwargs:
 			if type(kwargs['cluster']) == int:
 				mapiter.good_clusters = np.intersect1d([kwargs['cluster']], self.kilodata.good_clusters)
@@ -741,8 +741,8 @@ class OpenEphysNPX(OpenEphysBase):
 	def plotPos(self, jumpmax=None, show=True, **kwargs):
 		super().plotPos(jumpmax, show, **kwargs)
 
-	def plotMaps(self, plot_type='map', **kwargs):
-		super().plotMaps(plot_type, **kwargs)
+	def plotMaps(self, **kwargs):
+		super().plotMaps(**kwargs)
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
@@ -884,8 +884,8 @@ class OpenEphysNWB(OpenEphysBase):
 		xy = super().plotPos(jumpmax, show)
 		return xy
 
-	def plotMaps(self, plot_type='map', **kwargs):
-		super().plotMaps(plot_type, **kwargs)
+	def plotMaps(self, **kwargs):
+		super().plotMaps(**kwargs)
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
@@ -1015,8 +1015,8 @@ class OpenEphysBinary(OpenEphysBase):
 		xy = super().plotPos(jumpmax, show)
 		return xy
 
-	def plotMaps(self, plot_type='map', **kwargs):
-		super().plotMaps(plot_type, **kwargs)
+	def plotMaps(self, **kwargs):
+		super().plotMaps(**kwargs)
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
